MultiFlipCardController class

Controller to programmatically control the MultiFlipCard

Constructors

MultiFlipCardController()

Properties

currentBackIndex int
Get the current back widget index
no setter
currentBackKey String?
Get the current back widget key (Map backs mode). Returns null in List mode.
no setter
hashCode int
The hash code for this object.
no setterinherited
isFlipped bool
Check if the card is currently flipped
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

flip() → void
Flip the card (toggle between front and back)
flipToBack(int index) → void
Flip to a specific back widget by index
flipToBackKey(String key) → void
Flip to a specific back widget by key (Map backs mode)
flipToFront() → void
Flip to the front widget
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited