multi_flip_card library
Classes
- FlipCardInheritedWidget
- Inherited widget to provide flip functionality to child widgets
- FlipTrigger
- Widget that can trigger flip when tapped
- MultiFlipCard
- A multi flip card widget that can flip between front and multiple back widgets with smooth animation effects.
- MultiFlipCardController
- Controller to programmatically control the MultiFlipCard
Enums
- FlipAction
- Actions that can be performed when FlipTrigger is tapped
- FlipDirection
- Direction for the flip animation